==> ogre-13.1.1-1-x86_64.pkg.tar.zst: usr/share/doc/OGRE/api/html/class_ogre_1_1_vertex_data.js <==
var class_ogre_1_1_vertex_data =
[
    [ "HardwareAnimationData", "struct_ogre_1_1_vertex_data_1_1_hardware_animation_data.html", "struct_ogre_1_1_vertex_data_1_1_hardware_animation_data" ],
    [ "HardwareAnimationDataList", "class_ogre_1_1_vertex_data.html#a9b0be9ce516c0b04e3565317e6186b15", null ],
    [ "VertexData", "class_ogre_1_1_vertex_data.html#a2396c78b8d5353f2f0f0fa24467550ac", null ],
    [ "VertexData", "class_ogre_1_1_vertex_data.html#a7a588ae595eadd30f8f245afed2a5734", null ],
    [ "~VertexData", "class_ogre_1_1_vertex_data.html#acb2f442725d39e33a39f4d07f317fdc0", null ],
    [ "clone", "class_ogre_1_1_vertex_data.html#a8a5d29ce675bba00f202d59b049477ed", null ],
    [ "prepareForShadowVolume", "class_ogre_1_1_vertex_data.html#a35751c0e63acf6def8a1cf101abd1b28", null ],
    [ "reorganiseBuffers", "class_ogre_1_1_vertex_data.html#a106603d9d4d6c2f6e0d5eb6c25eb7c32", null ],
    [ "reorganiseBuffers", "class_ogre_1_1_vertex_data.html#ad1c61a5203430f896579775636e23d25", null ],
    [ "closeGapsInBindings", "class_ogre_1_1_vertex_data.html#a155a22e5f5cf3cc46c8890a81383ee19", null ],
    [ "removeUnusedBuffers", "class_ogre_1_1_vertex_data.html#a9c8caba4952eb43bced5051c3e3bff1f", null ],
    [ "convertPackedColour", "class_ogre_1_1_vertex_data.html#a0f6c57d776f87c08bb6fd6515f26270e", null ],
    [ "allocateHardwareAnimationElements", "class_ogre_1_1_vertex_data.html#ad6f88995ea6fd3d8aeabd4b0cc90abc4", null ],
    [ "vertexDeclaration", "class_ogre_1_1_vertex_data.html#abac9cde9c001b97cf1fea7fd05b79cf4", null ],
    [ "vertexBufferBinding", "class_ogre_1_1_vertex_data.html#a1cf7dacb2a133d71620abd59cb3180b0", null ],
    [ "mDeleteDclBinding", "class_ogre_1_1_vertex_data.html#a4cad19bf7cc1610d24d62f06149f9107", null ],
    [ "vertexStart", "class_ogre_1_1_vertex_data.html#aa3dca90128a99a8cdcd68201ad2c2f93", null ],
    [ "vertexCount", "class_ogre_1_1_vertex_data.html#a0b59b63cc2dbede1c5fc6a932fd2c10d", null ],
    [ "hwAnimationDataList", "class_ogre_1_1_vertex_data.html#a43acb3f735c2d4bdfdfbfdebc26dc52e", null ],
    [ "hwAnimDataItemsUsed", "class_ogre_1_1_vertex_data.html#af24c57003d9fa3d717ca16e7f5becb41", null ],
    [ "hardwareShadowVolWBuffer", "class_ogre_1_1_vertex_data.html#a154124cc2848e3eae62e9d508f45e921", null ]
];

==> ogre-13.4.4-1-x86_64.pkg.tar.zst: usr/share/doc/OGRE/api/html/class_ogre_1_1_vertex_data.js <==
var class_ogre_1_1_vertex_data =
[
    [ "HardwareAnimationData", "struct_ogre_1_1_vertex_data_1_1_hardware_animation_data.html", "struct_ogre_1_1_vertex_data_1_1_hardware_animation_data" ],
    [ "HardwareAnimationDataList", "class_ogre_1_1_vertex_data.html#a9b0be9ce516c0b04e3565317e6186b15", null ],
    [ "VertexData", "class_ogre_1_1_vertex_data.html#a2396c78b8d5353f2f0f0fa24467550ac", null ],
    [ "VertexData", "class_ogre_1_1_vertex_data.html#a7a588ae595eadd30f8f245afed2a5734", null ],
    [ "~VertexData", "class_ogre_1_1_vertex_data.html#acb2f442725d39e33a39f4d07f317fdc0", null ],
    [ "clone", "class_ogre_1_1_vertex_data.html#a8a5d29ce675bba00f202d59b049477ed", null ],
    [ "prepareForShadowVolume", "class_ogre_1_1_vertex_data.html#a35751c0e63acf6def8a1cf101abd1b28", null ],
    [ "convertVertexElement", "class_ogre_1_1_vertex_data.html#ac577d5d263134103a731d659926a6b58", null ],
    [ "reorganiseBuffers", "class_ogre_1_1_vertex_data.html#a106603d9d4d6c2f6e0d5eb6c25eb7c32", null ],
    [ "reorganiseBuffers", "class_ogre_1_1_vertex_data.html#ad1c61a5203430f896579775636e23d25", null ],
    [ "closeGapsInBindings", "class_ogre_1_1_vertex_data.html#a155a22e5f5cf3cc46c8890a81383ee19", null ],
    [ "removeUnusedBuffers", "class_ogre_1_1_vertex_data.html#a9c8caba4952eb43bced5051c3e3bff1f", null ],
    [ "convertPackedColour", "class_ogre_1_1_vertex_data.html#a0f6c57d776f87c08bb6fd6515f26270e", null ],
    [ "allocateHardwareAnimationElements", "class_ogre_1_1_vertex_data.html#ad6f88995ea6fd3d8aeabd4b0cc90abc4", null ],
    [ "_cloneRemovingBlendData", "class_ogre_1_1_vertex_data.html#ab530a06a3fa05c89ff61350718f6fdb9", null ],
    [ "vertexDeclaration", "class_ogre_1_1_vertex_data.html#abac9cde9c001b97cf1fea7fd05b79cf4", null ],
    [ "vertexBufferBinding", "class_ogre_1_1_vertex_data.html#a1cf7dacb2a133d71620abd59cb3180b0", null ],
    [ "mDeleteDclBinding", "class_ogre_1_1_vertex_data.html#a4cad19bf7cc1610d24d62f06149f9107", null ],
    [ "vertexStart", "class_ogre_1_1_vertex_data.html#aa3dca90128a99a8cdcd68201ad2c2f93", null ],
    [ "vertexCount", "class_ogre_1_1_vertex_data.html#a0b59b63cc2dbede1c5fc6a932fd2c10d", null ],
    [ "hwAnimationDataList", "class_ogre_1_1_vertex_data.html#a43acb3f735c2d4bdfdfbfdebc26dc52e", null ],
    [ "hwAnimDataItemsUsed", "class_ogre_1_1_vertex_data.html#af24c57003d9fa3d717ca16e7f5becb41", null ],
    [ "hardwareShadowVolWBuffer", "class_ogre_1_1_vertex_data.html#a154124cc2848e3eae62e9d508f45e921", null ]
];
